package com.ruoyi.zongzhi.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.zongzhi.mapper.TcGovernmentWebMapper;
import com.ruoyi.zongzhi.domain.TcGovernmentWeb;
import com.ruoyi.zongzhi.service.ITcGovernmentWebService;

/**
 * 政府网站Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-08-10
 */
@Service
public class TcGovernmentWebServiceImpl implements ITcGovernmentWebService 
{
    @Autowired
    private TcGovernmentWebMapper tcGovernmentWebMapper;

    /**
     * 查询政府网站
     * 
     * @param id 政府网站主键
     * @return 政府网站
     */
    @Override
    public TcGovernmentWeb selectTcGovernmentWebById(Long id)
    {
        return tcGovernmentWebMapper.selectTcGovernmentWebById(id);
    }

    /**
     * 查询政府网站列表
     * 
     * @param tcGovernmentWeb 政府网站
     * @return 政府网站
     */
    @Override
    public List<TcGovernmentWeb> selectTcGovernmentWebList(TcGovernmentWeb tcGovernmentWeb)
    {
        return tcGovernmentWebMapper.selectTcGovernmentWebList(tcGovernmentWeb);
    }

    /**
     * 新增政府网站
     * 
     * @param tcGovernmentWeb 政府网站
     * @return 结果
     */
    @Override
    public int insertTcGovernmentWeb(TcGovernmentWeb tcGovernmentWeb)
    {
        tcGovernmentWeb.setCreateTime(DateUtils.getNowDate());
        return tcGovernmentWebMapper.insertTcGovernmentWeb(tcGovernmentWeb);
    }

    /**
     * 修改政府网站
     * 
     * @param tcGovernmentWeb 政府网站
     * @return 结果
     */
    @Override
    public int updateTcGovernmentWeb(TcGovernmentWeb tcGovernmentWeb)
    {
        tcGovernmentWeb.setUpdateTime(DateUtils.getNowDate());
        return tcGovernmentWebMapper.updateTcGovernmentWeb(tcGovernmentWeb);
    }

    /**
     * 批量删除政府网站
     * 
     * @param ids 需要删除的政府网站主键
     * @return 结果
     */
    @Override
    public int deleteTcGovernmentWebByIds(Long[] ids)
    {
        return tcGovernmentWebMapper.deleteTcGovernmentWebByIds(ids);
    }

    /**
     * 删除政府网站信息
     * 
     * @param id 政府网站主键
     * @return 结果
     */
    @Override
    public int deleteTcGovernmentWebById(Long id)
    {
        return tcGovernmentWebMapper.deleteTcGovernmentWebById(id);
    }
}
